"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseBucket = void 0;
class BaseBucket {
    constructor(db, prefix) {
        this.db = db;
        this.prefix = prefix;
    }
    async get(key) {
        return this.db.get(this.addPrefix(key));
    }
    async put(key, value) {
        return this.db.put(this.addPrefix(key), value);
    }
    async del(key) {
        return this.db.del(this.addPrefix(key));
    }
    async has(key) {
        return this.db.has(this.addPrefix(key));
    }
    async batch(operations) {
        return this.db.batch(operations.map((op) => {
            return Object.assign(Object.assign({}, op), { key: this.addPrefix(op.key) });
        }));
    }
    iterator(options) {
        return this.db.iterator(Object.assign(Object.assign({}, options), { prefix: this.addPrefix(options.prefix) }));
    }
    bucket(prefix) {
        return this.db.bucket(this.addPrefix(prefix));
    }
    rangeBucket(prefix) {
        return this.db.rangeBucket(this.addPrefix(prefix));
    }
    addPrefix(value) {
        return value !== undefined
            ? Buffer.concat([this.prefix, value])
            : this.prefix;
    }
}
exports.BaseBucket = BaseBucket;
//# sourceMappingURL=bucket.js.map