"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BUFFER_MAX = exports.BUFFER_MIN = exports.writeHex = exports.sizeHex = exports.writeBuffer = exports.readBuffer = exports.sizeBuffer = exports.writeString = exports.readString = exports.sizeString = exports.makeID = exports.assert = exports.assertType = exports.assertLen = void 0;
exports.assertLen = (check) => {
    exports.assert(check, new RangeError('Invalid length for database key.'));
};
exports.assertType = (check) => {
    exports.assert(check, new TypeError('Invalid type for database key.'));
};
exports.assert = (check, err) => {
    err = err || new Error('Assertion error.');
    if (!check) {
        if (Error.captureStackTrace) {
            Error.captureStackTrace(err, exports.assert);
        }
        throw err;
    }
};
exports.makeID = (id) => {
    let parsed;
    if (typeof id === 'string') {
        exports.assert(id.length === 1);
        parsed = id.charCodeAt(0);
    }
    else {
        parsed = id;
    }
    exports.assert((parsed & 0xff) === parsed);
    exports.assert(parsed !== 0xff);
    return parsed;
};
exports.sizeString = (value, encoding) => {
    return 1 + Buffer.byteLength(value, encoding);
};
exports.readString = (buf, offset, encoding) => {
    exports.assertLen(offset + 1 <= buf.length);
    exports.assertLen(offset + 1 + buf[offset] <= buf.length);
    return buf.toString(encoding, offset + 1, offset + 1 + buf[offset]);
};
exports.writeString = (buf, value, offset, encoding, length) => {
    const size = Buffer.byteLength(value, encoding);
    exports.assertType(size <= 255);
    exports.assertLen(offset + 1 <= buf.length);
    buf[offset] = size;
    if (size > 0) {
        exports.assertType(buf.write(value, offset + 1, length, encoding) === size);
    }
    return 1 + size;
};
exports.sizeBuffer = (buf) => {
    return 1 + buf.length;
};
exports.readBuffer = (buf, offset) => {
    exports.assertLen(offset + 1 <= buf.length);
    exports.assertLen(offset + 1 + buf[offset] <= buf.length);
    return buf.slice(offset + 1, offset + 1 + buf[offset]);
};
exports.writeBuffer = (buf, value, offset) => {
    exports.assertLen(value.length <= 255);
    exports.assertLen(offset + 1 <= buf.length);
    buf[offset] = value.length;
    exports.assertLen(value.copy(buf, offset + 1) === value.length);
    return 1 + value.length;
};
exports.sizeHex = (value) => {
    if (Buffer.isBuffer(value)) {
        return value.length;
    }
    return value.length >>> 1;
};
exports.writeHex = (buf, value, offset, length) => {
    if (Buffer.isBuffer(value)) {
        return value.copy(buf, offset);
    }
    return buf.write(value, offset, length, 'hex');
};
exports.BUFFER_MIN = Buffer.alloc(0);
exports.BUFFER_MAX = Buffer.alloc(255, 0xff);
//# sourceMappingURL=utils.js.map