"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultWalletDB = void 0;
const ethers_1 = require("ethers");
class DefaultWalletDB {
    constructor(db) {
        this.db = db;
    }
    async putKeystore(keystore) {
        const key = Buffer.from(ethers_1.ethers.utils.getAddress(keystore.address));
        const value = Buffer.from(JSON.stringify(keystore));
        await this.db.put(key, value);
    }
    async getKeystore(address) {
        const key = Buffer.from(ethers_1.ethers.utils.getAddress(address));
        const value = await this.db.get(key);
        if (value === null) {
            throw new Error('Keystore file does not exist.');
        }
        return JSON.parse(value.toString());
    }
    async hasKeystore(address) {
        try {
            await this.getKeystore(address);
        }
        catch (err) {
            if (err.message.includes('Keystore file does not exist.')) {
                return false;
            }
            else {
                throw err;
            }
        }
        return true;
    }
    async listAccounts() {
        const keystores = await this.db.iterator().values();
        return keystores.map((keystore) => {
            const address = JSON.parse(keystore.toString()).address;
            return ethers_1.ethers.utils.getAddress(address);
        });
    }
}
exports.DefaultWalletDB = DefaultWalletDB;
//# sourceMappingURL=wallet-db.js.map