"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultWallet = void 0;
const ethers_1 = require("ethers");
const core_utils_1 = require("@eth-optimism/core-utils");
class DefaultWallet {
    constructor(walletdb) {
        this.walletdb = walletdb;
        this.unlocked = {};
    }
    async listAccounts() {
        return this.walletdb.listAccounts();
    }
    async createAccount(password) {
        const wallet = ethers_1.ethers.Wallet.createRandom();
        const keystore = await wallet.encrypt(password);
        await this.walletdb.putKeystore(JSON.parse(keystore));
        return wallet.address;
    }
    async unlockAccount(address, password) {
        if (!(await this.walletdb.hasKeystore(address))) {
            throw new Error('Account does not exist.');
        }
        const keystore = await this.walletdb.getKeystore(address);
        let wallet;
        try {
            wallet = await ethers_1.ethers.Wallet.fromEncryptedJson(JSON.stringify(keystore), password);
        }
        catch (err) {
            throw new Error('Invalid account password.');
        }
        this.unlocked[address] = wallet;
    }
    async lockAccount(address) {
        delete this.unlocked[address];
    }
    async getSignatureProvider(address) {
        if (!(await this.walletdb.hasKeystore(address))) {
            throw new Error('Account does not exist.');
        }
        if (!(address in this.unlocked)) {
            throw new Error('Account is not unlocked.');
        }
        return new core_utils_1.DefaultSignatureProvider(this.unlocked[address]);
    }
    async sign(address, message) {
        if (!(await this.walletdb.hasKeystore(address))) {
            throw new Error('Account does not exist.');
        }
        if (!(address in this.unlocked)) {
            throw new Error('Account is not unlocked.');
        }
        return this.unlocked[address].signMessage(message);
    }
}
exports.DefaultWallet = DefaultWallet;
//# sourceMappingURL=wallet.js.map