"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostgresDB = void 0;
const core_utils_1 = require("@eth-optimism/core-utils");
const log = core_utils_1.getLogger('postgres-db');
const Pool = require('pg-pool');
class PostgresDB {
    constructor(host, port, user, password, database, poolSize = 10, ssl = false) {
        this.pool = new Pool({
            database,
            user,
            password,
            host,
            port,
            ssl,
            max: poolSize,
            idleTimeoutMillis: 10000,
            connectionTimeoutMillis: 1000,
        });
    }
    async select(query, client) {
        const c = client || (await this.pool.connect());
        try {
            const res = await c.query(query);
            return res.rows;
        }
        catch (e) {
            core_utils_1.logError(log, `Error executing query ${query}!`, e);
            throw e;
        }
        finally {
            if (!client) {
                c.release();
            }
        }
    }
    async execute(query, client) {
        const c = client || (await this.pool.connect());
        try {
            await c.query(query);
        }
        catch (e) {
            core_utils_1.logError(log, `Error executing query ${query}!`, e);
            throw e;
        }
        finally {
            if (!client) {
                c.release();
            }
        }
    }
    async startTransaction() {
        const client = await this.pool.connect();
        try {
            await client.query('BEGIN');
            return client;
        }
        catch (e) {
            core_utils_1.logError(log, `Error creating a transaction`, e);
            throw e;
        }
    }
    async commit(client) {
        try {
            await client.query('COMMIT');
        }
        catch (e) {
            core_utils_1.logError(log, `Error committing transaction!`, e);
            throw e;
        }
        finally {
            client.release();
        }
    }
    async rollback(client) {
        try {
            await client.query('ROLLBACK');
        }
        catch (e) {
            core_utils_1.logError(log, `Error rolling back transaction!`, e);
            throw e;
        }
        finally {
            client.release();
        }
    }
}
exports.PostgresDB = PostgresDB;
//# sourceMappingURL=postgres.js.map