"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const setup_1 = require("../setup");
const debug_1 = require("debug");
const db_1 = require("../../src/types/db");
const app_1 = require("../../src/app");
const log = debug_1.default('db');
describe('RangeDB', () => {
    let db;
    beforeEach(async () => {
        db = app_1.newInMemoryDB();
    });
    describe('batch', () => {
        it('should process put batch correctly', async () => {
            const testBuff = Buffer.from(`test`);
            const testBuff2 = Buffer.from(`test2`);
            const batch = [
                {
                    type: db_1.PUT_BATCH_TYPE,
                    key: testBuff,
                    value: testBuff,
                },
                {
                    type: db_1.PUT_BATCH_TYPE,
                    key: testBuff2,
                    value: testBuff2,
                },
            ];
            try {
                await db.batch(batch);
            }
            catch (e) {
                throw e;
            }
            const res1 = await db.get(testBuff);
            res1.should.eql(testBuff, `Expected ${res1.toString()} to equal ${testBuff.toString()}`);
            const res2 = await db.get(testBuff2);
            res2.should.eql(testBuff2, `Expected ${res2.toString()} to equal ${testBuff2.toString()}`);
        });
        it('should process del batch correctly', async () => {
            const testBuff = Buffer.from(`test`);
            const testBuff2 = Buffer.from(`test2`);
            await db.put(testBuff, testBuff);
            await db.put(testBuff2, testBuff2);
            const batch = [
                {
                    type: db_1.DEL_BATCH_TYPE,
                    key: testBuff,
                },
                {
                    type: db_1.DEL_BATCH_TYPE,
                    key: testBuff2,
                },
            ];
            try {
                await db.batch(batch);
            }
            catch (e) {
                setup_1.assert.fail();
            }
            const res1 = await db.get(testBuff);
            setup_1.should.not.exist(res1, `${res1} should have been deleted`);
            const res2 = await db.get(testBuff2);
            setup_1.should.not.exist(res2, `${res2} should have been deleted`);
        });
        it('should process mixed batch correctly', async () => {
            const testBuff = Buffer.from(`test`);
            const testBuff2 = Buffer.from(`test2`);
            await db.put(testBuff, testBuff);
            await db.put(testBuff2, testBuff2);
            const testBuff3 = Buffer.from(`test2`);
            const batch = [
                {
                    type: db_1.DEL_BATCH_TYPE,
                    key: testBuff,
                },
                {
                    type: db_1.PUT_BATCH_TYPE,
                    key: testBuff2,
                    value: testBuff3,
                },
                {
                    type: db_1.PUT_BATCH_TYPE,
                    key: testBuff3,
                    value: testBuff3,
                },
            ];
            try {
                await db.batch(batch);
            }
            catch (e) {
                setup_1.assert.fail();
            }
            const res1 = await db.get(testBuff);
            setup_1.should.not.exist(res1, `${res1} should have been deleted`);
            const res2 = await db.get(testBuff2);
            res2.should.eql(testBuff3, `${res2.toString()} should have been updated to ${testBuff3.toString()}`);
            const res3 = await db.get(testBuff3);
            res3.should.eql(testBuff3, `${res3.toString()} should have been set to ${testBuff3.toString()}`);
        });
    });
});
//# sourceMappingURL=db.spec.js.map