"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployTokenContract = exports.TestListener = void 0;
const core_utils_1 = require("@eth-optimism/core-utils");
const assert = require("assert");
const ethers_1 = require("ethers");
const log = core_utils_1.getLogger('ethereum-test-utils', true);
class TestListener {
    constructor(sleepMillis = 50) {
        this.sleepMillis = sleepMillis;
        this.syncCompleted = false;
        this.received = [];
    }
    async onSyncCompleted() {
        this.syncCompleted = true;
    }
    async handle(t) {
        log.debug(`Received ${JSON.stringify(t)}`);
        if (this.received.length === 0) {
            this.received.push(t);
        }
        else if (this.received.filter((x) => core_utils_1.objectsEqual(x, t)).length === 0) {
            this.received.push(t);
        }
    }
    getReceived() {
        return this.received.splice(0);
    }
    async waitForReceive(numberToReceive = 1, timeoutMillis = -1) {
        const startTime = new Date().getTime();
        while (this.received.length < numberToReceive &&
            (timeoutMillis < 0 || new Date().getTime() - startTime < timeoutMillis)) {
            await core_utils_1.sleep(this.sleepMillis);
        }
        return this.getReceived();
    }
    async waitForSyncToComplete() {
        while (!this.syncCompleted) {
            await core_utils_1.sleep(this.sleepMillis);
        }
        return this.getReceived();
    }
    async assertNotReceivedAfter(millis) {
        await core_utils_1.sleep(millis);
        assert(this.getReceived().length === 0, 'Should not have received but did!');
    }
}
exports.TestListener = TestListener;
const TestToken = require('./contracts/build/TestToken.json');
exports.deployTokenContract = async (ownerWallet, initialSupply) => {
    const factory = new ethers_1.ethers.ContractFactory(TestToken.abi, TestToken.bytecode, ownerWallet);
    const tokenContract = await factory.deploy(initialSupply);
    return tokenContract.deployed();
};
//# sourceMappingURL=utils.js.map